Helper methods for testing updates to shinylive assets.
assets_install_copy(
assets_repo_dir,
...,
dir = assets_cache_dir(),
version = package_json_version(assets_repo_dir)
)assets_install_link(
assets_repo_dir,
...,
dir = assets_cache_dir(),
version = package_json_version(assets_repo_dir)
)
All method return invisible().
The local repository directory for shinylive assets
(e.g. posit-dev/shinylive)
Ignored.
The asset cache directory. Unless testing, the default behavior should be used.
The version of the assets being installed.
assets_install_copy(): Copies all shinylive assets from a local shinylive
repository (e.g.
posit-dev/shinylive). This
must be repeated for any change in the assets.
assets_install_link(): Creates a symlink of the local shinylive assets to the
cached assets directory. After the first installation, the assets will the
same as the source due to the symlink.
assets_download(), assets_ensure(), assets_cleanup()